=== modified file 'NEWS'
--- NEWS	2010-04-07 00:50:56 +0000
+++ NEWS	2010-04-08 04:34:03 +0000
@@ -22,6 +22,11 @@
 Bug Fixes
 *********
 
+* Make sure the ``ExecutablePath`` and ``InterpreterPath`` are set in
+  Apport crash reports, to avoid "This problem report applies to a program
+  which is not installed any more" error.
+  (Martin Pool, James Westby, #528114)
+
 * When invoked with a range revision, ``bzr log`` doesn't show revisions
   that are not part of the ancestry anymore.
   (Vincent Ladeuil, #474807)

=== renamed directory 'contrib/apport' => 'apport'
=== renamed file 'contrib/apport/bzr.conf' => 'apport/bzr-crashdb.conf'
=== modified file 'apport/source_bzr.py'
--- contrib/apport/source_bzr.py	2010-01-31 19:37:11 +0000
+++ apport/source_bzr.py	2010-04-08 04:34:03 +0000
@@ -32,8 +32,7 @@
 
 
 def add_info(report):
-
-    _add_log_tail()
+    _add_log_tail(report)
     if 'BzrPlugins' not in report:
         # may already be present in-process
         report['BzrPlugins'] = command_output(['bzr', 'plugins', '-v'])

=== modified file 'bzrlib/crash.py'
--- bzrlib/crash.py	2010-04-05 15:35:14 +0000
+++ bzrlib/crash.py	2010-04-08 04:34:03 +0000
@@ -143,8 +143,9 @@
     exc_type, exc_object, exc_tb = exc_info
 
     pr = Report()
-    # add_proc_info gets the executable and interpreter path, which is needed,
-    # plus some less useful stuff like the memory map
+    # add_proc_info gives you the memory map of the process, which is not so
+    # useful for Bazaar but does tell you what binary libraries are loaded.
+    # More importantly it sets the ExecutablePath, InterpreterPath, etc.
     pr.add_proc_info()
     pr.add_user_info()
 
@@ -165,6 +166,19 @@
     pr['PythonLoadedModules'] = _format_module_list()
     pr['BzrDebugFlags'] = pprint.pformat(debug.debug_flags)
 
+    # actually we'd rather file directly against the upstream product, but
+    # apport does seem to count on there being one in there; we might need to
+    # redirect it elsewhere anyhow
+    pr['SourcePackage'] = 'bzr'
+    pr['Package'] = 'bzr'
+
+    # tell apport to file directly against the bzr package using 
+    # <https://bugs.edge.launchpad.net/bzr/+bug/391015>
+    #
+    # XXX: unfortunately apport may crash later if the crashdb definition
+    # file isn't present
+    pr['CrashDb'] = 'bzr'
+
     tb_file = StringIO()
     traceback.print_exception(exc_type, exc_object, exc_tb, file=tb_file)
     pr['Traceback'] = tb_file.getvalue()

=== modified file 'bzrlib/tests/test_crash.py'
--- bzrlib/tests/test_crash.py	2010-02-23 07:43:11 +0000
+++ bzrlib/tests/test_crash.py	2010-04-08 04:34:03 +0000
@@ -67,6 +67,8 @@
             '(?m)^BzrVersion:') # should be in the traceback
         self.assertContainsRe(report, 'my error')
         self.assertContainsRe(report, 'AssertionError')
+        # see https://bugs.launchpad.net/bzr/+bug/528114
+        self.assertContainsRe(report, 'ExecutablePath')
         self.assertContainsRe(report, 'test_apport_report')
         # should also be in there
         self.assertContainsRe(report, '(?m)^CommandLine:')

=== modified file 'setup.py'
--- setup.py	2010-03-26 07:58:58 +0000
+++ setup.py	2010-04-08 04:34:03 +0000
@@ -712,6 +712,19 @@
         # easy_install one
         DATA_FILES = [('man/man1', ['bzr.1'])]
 
+    if sys.platform != 'win32':
+        # see https://wiki.kubuntu.org/Apport/DeveloperHowTo
+        #
+        # checking the paths and hardcoding the check for root is a bit gross,
+        # but I don't see a cleaner way to find out the locations in a way
+        # that's going to align with the hardcoded paths in apport.
+        if os.geteuid() == 0:
+            DATA_FILES += [
+                ('/usr/share/apport/package-hooks',
+                    ['apport/source_bzr.py']),
+                ('/etc/apport/crashdb.conf.d/',
+                    ['apport/bzr-crashdb.conf']),]
+
     # std setup
     ARGS = {'scripts': ['bzr'],
             'data_files': DATA_FILES,

